@@ -10,7 +10,7 @@ use Moose;
 use namespace::autoclean;
 use Dist::Zilla::File::OnDisk;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 our $AUTHORITY = 'cpan:CHIM'; # AUTHORITY
 
 with qw(
@@ -24,15 +24,15 @@ has readme => (
 );
 
 has user => (
-    is      => 'rw',
-    isa     => 'Str',
-    default => sub { '' },
+    is          => 'rw',
+    isa         => 'Str',
+    predicate   => 'has_user',
 );
 
 has repo => (
-    is      => 'rw',
-    isa     => 'Str',
-    default => sub { '' },
+    is          => 'rw',
+    isa         => 'Str',
+    predicate   => 'has_repo',
 );
 
 has branch => (
@@ -47,11 +47,15 @@ has vector => (
     default => sub { 0 },
 );
 
+
 sub after_build {
     my ($self) = @_;
 
-    if ($self->user eq '' || $self->repo eq '') {
-        $self->log("Missing option: user or repo.");
+    # fill user/repo using distmeta
+    $self->_try_distmeta()      unless $self->has_user && $self->has_repo;
+
+    unless ( $self->has_user && $self->has_repo ) {
+        $self->log( "Missing option: user or repo." );
         return;
     }
 
@@ -98,6 +102,62 @@ sub after_build {
     return;
 }
 
+
+# attempt to fill user/repo using distmeta resources
+sub _try_distmeta {
+    my ( $self ) = @_;
+
+    my $meta = $self->zilla->distmeta;
+
+    return      unless exists $meta->{resources};
+
+    # possible list of sources for user/repo:
+    # resources.repository.web
+    # resources.repository.url
+    # resources.homepage
+    my @sources = (
+        (
+            exists $meta->{resources}{repository}
+                ? grep { defined $_ } @{ $meta->{resources}{repository} }{qw( web url )}
+                : ()
+        ),
+        (
+            exists $meta->{resources}{homepage}
+                ? $meta->{resources}{homepage}
+                : ()
+        ),
+    );
+
+    # remove duplicates
+    @sources = do {
+        my %seen = map { $_ => 1 } @sources;
+        sort keys %seen;
+    };
+
+    for my $source ( @sources ) {
+        # dont overwrite
+        last        if $self->has_user && $self->has_repo;
+
+        next        unless $source =~ m/github\.com/i;
+
+        # taken from Dist/Zilla/Plugin/GithubMeta.pm
+        # thanks to BINGOS!
+        my ( $user, $repo ) = $source =~ m{
+            github\.com              # the domain
+            [:/] ([^/]+)             # the username (: for ssh, / for http)
+            /    ([^/]+?) (?:\.git)? # the repo name
+            $
+        }ix;
+
+        next        unless defined $user && defined $repo;
+
+        $self->user( $user );
+        $self->repo( $repo );
+
+        last;
+    }
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1; # End of Dist::Zilla::Plugin::TravisCI::StatusBadge
@@ -114,7 +174,7 @@ Dist::Zilla::Plugin::TravisCI::StatusBadge - Get Travis CI status badge for your
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -125,11 +185,19 @@ version 0.004
     branch = foo        ;; "master" by default
     vector = 1          ;; SVG image
 
+    ; or just
+    [TravisCI::StatusBadge]
+    ;; shortcut for "png image; master branch; user/repo from meta resources"
+
 =head1 DESCRIPTION
 
 Scans dist files if a C<README.md> file has found, a Travis CI C<build status> badge will be added before the B<VERSION> header.
 Use L<Dist::Zilla::Plugin::ReadmeAnyFromPod> in markdown mode or any other plugin to generate README.md.
 
+=for Pod::Coverage after_build
+
+=for Pod::Coverage _try_distmeta
+
 =head1 OPTIONS
 
 =head2 readme
@@ -138,11 +206,13 @@ The name of file to inject build status badge. Default value is C<README.md>.
 
 =head2 user
 
-Github username. Required.
+Github username. Might be obtained automatically (if not given) from META resources (C<resources.homepage>,
+C<resources.repository.web>, C<resources.repository.url>).
 
 =head2 repo
 
-Github repository name. Required.
+Github repository name. Might be obtained automatically (if not given) from META resources
+(C<resources.homepage>, C<resources.repository.web>, C<resources.repository.url>).
 
 =head2 branch
 
@@ -159,6 +229,10 @@ L<https://travis-ci.org>
 
 L<Dist::Zilla::Plugin::ReadmeAnyFromPod>
 
+L<Dist::Zilla::Plugin::GithubMeta>
+
+L<Dist::Zilla::Role::AfterBuild>
+
 L<Dist::Zilla>
 
 =head1 AUTHOR
